==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PreRegistrationInlineHook.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PreRegistrationInlineHook
 */
@JsonPropertyOrder({ PreRegistrationInlineHook.JSON_PROPERTY_INLINE_HOOK_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PreRegistrationInlineHook implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INLINE_HOOK_ID = "inlineHookId";
    private String inlineHookId;

    public PreRegistrationInlineHook() {
    }

    public PreRegistrationInlineHook inlineHookId(String inlineHookId) {

        this.inlineHookId = inlineHookId;
        return this;
    }

    /**
     * Get inlineHookId
     *
     * @return inlineHookId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INLINE_HOOK_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getInlineHookId() {
        return inlineHookId;
    }

    @JsonProperty(JSON_PROPERTY_INLINE_HOOK_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInlineHookId(String inlineHookId) {
        this.inlineHookId = inlineHookId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PreRegistrationInlineHook preRegistrationInlineHook = (PreRegistrationInlineHook) o;
        return Objects.equals(this.inlineHookId, preRegistrationInlineHook.inlineHookId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(inlineHookId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PreRegistrationInlineHook {\n");
        sb.append("    inlineHookId: ").append(toIndentedString(inlineHookId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PreRegistrationInlineHook.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PreRegistrationInlineHook
 */
@JsonPropertyOrder({ PreRegistrationInlineHook.JSON_PROPERTY_INLINE_HOOK_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PreRegistrationInlineHook implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INLINE_HOOK_ID = "inlineHookId";
    private String inlineHookId;

    public PreRegistrationInlineHook() {
    }

    public PreRegistrationInlineHook inlineHookId(String inlineHookId) {

        this.inlineHookId = inlineHookId;
        return this;
    }

    /**
     * Get inlineHookId
     *
     * @return inlineHookId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INLINE_HOOK_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getInlineHookId() {
        return inlineHookId;
    }

    @JsonProperty(JSON_PROPERTY_INLINE_HOOK_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInlineHookId(String inlineHookId) {
        this.inlineHookId = inlineHookId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PreRegistrationInlineHook preRegistrationInlineHook = (PreRegistrationInlineHook) o;
        return Objects.equals(this.inlineHookId, preRegistrationInlineHook.inlineHookId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(inlineHookId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PreRegistrationInlineHook {\n");
        sb.append("    inlineHookId: ").append(toIndentedString(inlineHookId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
